@@ -8,13 +8,15 @@ from crum import get_current_request
 from opaque_keys.edx.keys import CourseKey
 
 from eox_hooks.edxapp_wrapper.courses import get_item_not_found_exception, get_load_single_xblock
+from eox_hooks.edxapp_wrapper.models import get_certificate_model
 from eox_hooks.serializers import CertificateSerializer, CourseSerializer, UserSerializer
 from eox_hooks.tasks import create_enrollments_for_program
 from eox_hooks.utils import _get_course, flatten_dict, get_trigger_settings
 
+COURSE_PASSING_GRADE = 1
 ItemNotFoundError = get_item_not_found_exception()
 load_single_xblock = get_load_single_xblock()
-COURSE_PASSING_GRADE = 1
+GeneratedCertificate = get_certificate_model()
 log = logging.getLogger(__name__)
 
 
@@ -61,6 +63,9 @@ def post_to_webhook_url(**kwargs):
 
     if trigger_settings.get("send_certificate_data", False):
         certificate = kwargs.get("certificate", {})
+        certificate = GeneratedCertificate.objects.get(
+            user__id=certificate.user.id, course_id=certificate.course.course_key,
+        )
         extended_data = get_extended_certificate_data(certificate)
         data.update(extended_data)
 
@@ -144,8 +149,8 @@ def trigger_enrollments_creation(**kwargs):
         course_key (str): course identifier.
         user (User): user that just enrolled in the course.
     """
-    course = _get_course(kwargs.get("course_key"))
-    user = kwargs.get("user")
+    enrollment = kwargs.get("enrollment")
+    course = _get_course(enrollment.course.course_key)
 
     followup_enrollments = getattr(course, "other_course_settings", {}).get(
         "EDNX_TRIGGER_FOLLOWUP_ENROLLMENTS"
@@ -154,7 +159,9 @@ def trigger_enrollments_creation(**kwargs):
     if not followup_enrollments:
         return
 
-    create_enrollments_for_program.delay(user.username, followup_enrollments)
+    create_enrollments_for_program.delay(
+        enrollment.user.pii.username, followup_enrollments,
+    )
 
 
 def trigger_grades_assignment(**kwargs):
@@ -189,10 +196,10 @@ def trigger_grades_assignment(**kwargs):
         User `U` obtains 90% of the grade in X, then 1 is assigned to the component x.
 
     Keyword args:
-        certificate (GeneratedCertificate): certificate generated by the course.
+        certificate (CertificateData): certificate data generated by the course.
     """
     certificate = kwargs.get("certificate")
-    course = _get_course(certificate.course_id)
+    course = _get_course(certificate.course.course_key)
 
     grades_assignment_settings = getattr(course, "other_course_settings", {}).get(
         "EDNX_TRIGGER_GRADES_ASSIGNMENT", {}
